"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.isEnvCi = exports.isEnvSandbox = exports.detectCliMode = exports.CLI_MODE_PROPERTY = exports.CI_PROPERTY = void 0;
/**
 * Motivation and Concepts of CLI Modes
 *
 * The CLI can execute in different environments:
 * - As actual CLI used in the console. e.g. used by a developer to repetitively test a page
 * - In the test setup to ensure functionality. e.g. in it's repository's test code
 * - On the server of a application. e.g. https://lighthouse-metrics.com/
 * - In the CI of a code versioning service. e.g. GitHub
 *
 * Used as is, the CLI is designed to have good DX, developer experience and lean setup costs.
 * A couple of examples for good DX are prompts, file generation, visualizing data, reporting progress etc.
 *
 * This obviously leads to a default configuration which is beneficial for one environment or usage but,
 * but not for many others. As an example a automatic prompt is helpful for a human that forgot to configure a specific setting,
 * but in a CI setup it should fail with an error requesting the missing setting.
 *
 * To work around it we have to adopt the configuration of the CLI depending on the environment.
 * e.g. don't open a report automatically if it runs in the CI `--openReport false` or `-e false`.
 *
 * As an example let's look at the CLI configuration if we execute it in the CI with default settings:
 *
 * `npx user-flow -i false -e false -f json -f md -f html`
 *
 * Here the explanation why we use all the parameters:
 * - `--openReport false` (`-e`) - No one will look at it in the CI
 * - `--interactive false` (`-i`) - No one can answer
 * - `--format json --format md` (`-f`) - Because we need it for the GitHub action as md text and json
 * - `--format html` - We need to maintain the original formats too
 * - __headless__ - we need to configure the lighthouse for a headless run
 *
 * With different test sets the above gets hard to maintain.
 *
 * This is where the CLI mode feature can help. It detects the current environment and provides it for other parts of the CLI.
 * We can use it to implement environment based default configurations to improve DX and reduce the maintenance costs.
 *
 * The above command can with a pre-configuration would look like this:
 *
 * `npx user-flow`
 *
 * To detect if it runs in a CI we check the `process.env` property for either `true` or `1`.
 * To "enable" sandbox mode we programmatically have to set `process.env.CI` to `SANDBOX`.
 *
 */
const env = process.env;
exports.CI_PROPERTY = 'CI';
exports.CLI_MODE_PROPERTY = '__CLI_MODE__';
/**
 * detects the current CLI mode
 */
function detectCliMode() {
    return isEnvCi() ? 'CI' : isEnvSandbox() ? 'SANDBOX' : 'DEFAULT';
}
exports.detectCliMode = detectCliMode;
/**
 * If the CLI is under test the user has to set the env property `CI_PROPERTY` to 'SANDBOX' programmatically to enable the sandbox mode.
 * This function is here to check this.
 */
function isEnvSandbox() {
    return env[exports.CI_PROPERTY] === 'SANDBOX';
}
exports.isEnvSandbox = isEnvSandbox;
/**
 * Determines if the CLI is running in a CI setup
 */
function isEnvCi() {
    /*
    Detailed links: https://github.com/push-based/user-flow/issues/15
    The following platforms have a CI key:
      CI=true - github
      CI=true - circleci
      CI=true - gitlab
      - travis
      CI=true
      CONTINUOUS_INTEGRATION=true
      CI=true - netlify
      - cirrus
      CI=true
      CONTINUOUS_INTEGRATION=true
      CI=true - appveyor
      CI=true - codeShip
      - dsari
      env.RUN_ID=??
      CI=true
      - taskCluster
      env.RUN_ID=??
      CI=1 - vercel
      - jenkins
      BUILD_NUMBER=??
      - teamCity
      BUILD_NUMBER=??
      Unknown:
      ??? - Azure Pipelines
     */
    if (env[exports.CI_PROPERTY] === 'SANDBOX') {
        return false;
    }
    const ciValue = env[exports.CI_PROPERTY] || // Travis CI, CircleCI, Cirrus CI, Gitlab CI, Appveyor, CodeShip, dsari
        env.CONTINUOUS_INTEGRATION || // Travis CI, Cirrus CI
        env.BUILD_NUMBER || // Jenkins, TeamCity
        env.RUN_ID; // TaskCluster, dsari
    return ciValue != null;
}
exports.isEnvCi = isEnvCi;
//# sourceMappingURL=cli-mode.js.map